*{
    box-sizing: border-box;
}

body{
    margin: 0 auto;
    max-width: 800px;
    padding: 1.45rem 1.0875rem;
}


.upload-form {
    display: flex;
    flex-direction: column;
    align-items: center;
}

.upload-form input {
    margin-bottom: 1rem;
}


#upload-button {
    text-align: center;
    margin-bottom: 1rem;
    min-width: 10rem;
    height: 2rem;
    border: #19662b solid 3px;
    background-color: #19662b;
    color: whitesmoke;
    border-radius: 8px;
}
#upload-button:hover {
    cursor: pointer;
    background-color: #28a745;
    border-color: #28a745;
    color: #fff;
}


#fileInput {
    padding: 20px;
    text-align: center;
    width: 100%;
    border: 2px dashed #007bff;
    border-radius: 10px;
    background-color: #f9f9f9;
    margin-bottom: 10px;
}

#upload-fileInput.highlight{
    border-color: #28a745;
    background-color: #e8f5e9;
}

#fileUrl {
    padding: 1rem;
    font-family: Consolas, Monaco, Courier New, monospace;
}

#preview img{
    border-radius: 20px;
}
